@@ -23,12 +23,12 @@ package azcopy
 import (
 	"errors"
 	"fmt"
+
 	"github.com/Azure/azure-storage-azcopy/v10/common"
 	"github.com/Azure/azure-storage-azcopy/v10/jobsAdmin"
 )
 
 type RemoveJobOptions struct {
-	JobID common.JobID
 }
 
 type RemoveJobResult struct {
@@ -36,14 +36,14 @@ type RemoveJobResult struct {
 }
 
 // RemoveJob removes a job with the specified JobID.
-func (c *Client) RemoveJob(opts RemoveJobOptions) (result RemoveJobResult, err error) {
+func (c *Client) RemoveJob(jobID common.JobID, opts RemoveJobOptions) (result RemoveJobResult, err error) {
 	result = RemoveJobResult{}
-	if opts.JobID.IsEmpty() {
+	if jobID.IsEmpty() {
 		return result, errors.New("remove job requires the JobID")
 	}
-	result.Count, err = jobsAdmin.RemoveSingleJobFiles(opts.JobID)
+	result.Count, err = jobsAdmin.RemoveSingleJobFiles(jobID)
 	if err != nil {
-		return result, fmt.Errorf("failed to remove log and job plan files for job %s due to error: %w", opts.JobID, err)
+		return result, fmt.Errorf("failed to remove log and job plan files for job %s due to error: %w", jobID, err)
 	}
 	return result, nil
 }
