@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"math/rand"
 
+	"github.com/Azure/azure-storage-azcopy/v10/azcopy"
 	"github.com/Azure/azure-storage-azcopy/v10/common"
 	"github.com/Azure/azure-storage-azcopy/v10/jobsAdmin"
 )
@@ -15,7 +16,7 @@ func addTransfer(e *common.CopyJobPartOrderRequest, transfer common.CopyTransfer
 	// dispatch the transfers once the number reaches NumOfFilesPerDispatchJobPart
 	// we do this so that in the case of large transfer, the transfer engine can get started
 	// while the frontend is still gathering more transfers
-	if len(e.Transfers.List) == NumOfFilesPerDispatchJobPart {
+	if len(e.Transfers.List) == azcopy.NumOfFilesPerDispatchJobPart {
 		shuffleTransfers(e.Transfers.List)
 		resp := jobsAdmin.ExecuteNewCopyJobPartOrder(*e)
 
@@ -78,13 +79,13 @@ func dispatchFinalPart(e *common.CopyJobPartOrderRequest, cca *CookedCopyCmdArgs
 		}
 
 		if resp.ErrorMsg == common.ECopyJobPartOrderErrorType.NoTransfersScheduledErr() {
-			return NothingScheduledError
+			return azcopy.NothingScheduledError
 		}
 
 		return fmt.Errorf("copy job part order with JobId %s and part number %d failed because %s", e.JobID, e.PartNum, resp.ErrorMsg)
 	}
 
-	common.LogToJobLogWithPrefix(FinalPartCreatedMessage, common.LogInfo)
+	common.LogToJobLogWithPrefix(azcopy.FinalPartCreatedMessage, common.LogInfo)
 
 	// set the flag on cca, to indicate the enumeration is done
 	cca.isEnumerationComplete = true
