@@ -24,6 +24,7 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/Azure/azure-storage-azcopy/v10/azcopy"
 	"github.com/Azure/azure-storage-azcopy/v10/common"
 	"github.com/spf13/cobra"
 )
@@ -102,12 +103,12 @@ func init() {
 			//the resource to set properties of is set as src
 			raw.src = args[0]
 			// We support DFS by using blob end-point of the account. We replace dfs by blob in src and dst
-			if src := InferArgumentLocation(raw.src); src == common.ELocation.BlobFS() {
+			if src := azcopy.InferArgumentLocation(raw.src); src == common.ELocation.BlobFS() {
 				raw.src = strings.Replace(raw.src, ".dfs", ".blob", 1)
 				glcm.Info("Switching to use blob endpoint on source account.")
 			}
 
-			srcLocationType := InferArgumentLocation(raw.src)
+			srcLocationType := azcopy.InferArgumentLocation(raw.src)
 			if raw.fromTo == "" {
 				switch srcLocationType {
 				case common.ELocation.Blob():
