@@ -13,7 +13,7 @@ import (
 // dataSchemaVersion defines the data schema version of JobPart order files supported by
 // current version of azcopy
 // To be Incremented every time when we release azcopy with changed dataSchema
-const DataSchemaVersion common.Version = 19
+const DataSchemaVersion common.Version = 20
 
 const (
 	CustomHeaderMaxBytes = 256
@@ -80,6 +80,8 @@ type JobPartPlanHeader struct {
 	PreservePermissions     common.PreservePermissionsOption
 	PreserveInfo            bool
 	PreservePOSIXProperties bool
+	// PosixPropertiesStyle represents whether to use 'standard' or 'amlfs' style posix properties
+	PosixPropertiesStyle common.PosixPropertiesStyle
 	// S2SGetPropertiesInBackend represents whether to enable get S3 objects' or Azure files' properties during s2s copy in backend.
 	S2SGetPropertiesInBackend bool
 	// S2SSourceChangeValidation represents whether user wants to check if source has changed after enumerating.
