@@ -3,6 +3,7 @@ package ste
 import (
 	"errors"
 	"fmt"
+
 	"github.com/Azure/azure-storage-azcopy/v10/common"
 )
 
@@ -22,7 +23,7 @@ func (s *blobSymlinkSender) getExtraProperties() error {
 				return errors.New("sanity check: GetUNIXProperties did not return symlink properties")
 			}
 
-			common.AddStatToBlobMetadata(statAdapter, s.metadataToApply)
+			common.AddStatToBlobMetadata(statAdapter, s.metadataToApply, s.jptm.Info().PosixPropertiesStyle)
 		}
 	}
 
